Learn R Programming

rquest (version 1.0.5)

rquest-package: rquest: Hypothesis Tests for Quantiles and Quantile-Based Measures

Description

Functions to conduct hypothesis tests and derive confidence intervals for quantiles, linear combinations of quantiles, ratios of dependent linear combinations and differences and ratios of all of the above for comparisons between independent samples. Additionally, quantile-based measures of inequality are also considered.

Arguments

Author

Maintainer: Shenal Dedduwakumara shenal.dedduwakumara@adelaide.edu.au

Authors:

See Also